@@ -1,4 +1,3 @@
-
 //! Update an import
 //! 
 //! An import can be updated with credentials or a project choice by passing in the appropriate parameters in this API
@@ -204,42 +203,6 @@ impl From<::reqwest::blocking::Body> for Content<::reqwest::blocking::Body> {
     }
 }
 
-#[cfg(feature = "hyper")]
-impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>> for Content<::hyper::Body> {
-    type Error = crate::v1_1_4::ApiError;
-
-    fn try_from(value: &::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>) -> Result<Self, Self::Error> {
-        Ok(
-            Self::new(::serde_json::to_vec(value)?.into())
-            .with_content_type(&b"application/json"[..])
-        )
-    }
-}
-
-#[cfg(feature = "reqwest")]
-impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>> for Content<::reqwest::Body> {
-    type Error = crate::v1_1_4::ApiError;
-
-    fn try_from(value: &::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>) -> Result<Self, Self::Error> {
-        Ok(
-            Self::new(::serde_json::to_vec(value)?.into())
-            .with_content_type(&b"application/json"[..])
-        )
-    }
-}
-
-#[cfg(feature = "reqwest-blocking")]
-impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>> for Content<::reqwest::blocking::Body> {
-    type Error = crate::v1_1_4::ApiError;
-
-    fn try_from(value: &::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>) -> Result<Self, Self::Error> {
-        Ok(
-            Self::new(::serde_json::to_vec(value)?.into())
-            .with_content_type(&b"application/json"[..])
-        )
-    }
-}
-
 /// Types for body parameter in [`super::migrations_update_import`]
 pub mod body {
     #[allow(non_snake_case)]
@@ -276,4 +239,40 @@ pub mod body {
         #[serde(flatten)]
         pub additionalProperties: ::std::collections::HashMap<::std::borrow::Cow<'a, str>, ::serde_json::value::Value>
     }
+
+    #[cfg(feature = "hyper")]
+    impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>> for super::Content<::hyper::Body> {
+        type Error = crate::v1_1_4::ApiError;
+
+        fn try_from(value: &::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>) -> Result<Self, Self::Error> {
+            Ok(
+                Self::new(::serde_json::to_vec(value)?.into())
+                .with_content_type(&b"application/json"[..])
+            )
+        }
+    }
+
+    #[cfg(feature = "reqwest")]
+    impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>> for super::Content<::reqwest::Body> {
+        type Error = crate::v1_1_4::ApiError;
+
+        fn try_from(value: &::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>) -> Result<Self, Self::Error> {
+            Ok(
+                Self::new(::serde_json::to_vec(value)?.into())
+                .with_content_type(&b"application/json"[..])
+            )
+        }
+    }
+
+    #[cfg(feature = "reqwest-blocking")]
+    impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>> for super::Content<::reqwest::blocking::Body> {
+        type Error = crate::v1_1_4::ApiError;
+
+        fn try_from(value: &::std::option::Option<crate::v1_1_4::request::migrations_update_import::body::Json<'a>>) -> Result<Self, Self::Error> {
+            Ok(
+                Self::new(::serde_json::to_vec(value)?.into())
+                .with_content_type(&b"application/json"[..])
+            )
+        }
+    }
 }
